"""
Generated class for MedicationDispense. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Dosage import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *


class Performer(FhirBaseModel):
    """Indicates who or what performed the event.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept function: Who performed the dispense and what they did
    :param Reference actor: Individual who was performing
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "function": {"class_name": "CodeableConcept", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        function: "CodeableConcept" = None,
        actor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.function = function
        self.actor = actor

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationDispense":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationDispense":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substitution(FhirBaseModel):
    """Indicates whether or not substitution was made as part of the dispense.  In some cases, substitution will be expected but does not happen, in other cases substitution is not expected but does happen.  This block explains what substitution did or did not happen and why.  If nothing is specified, substitution was not done.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool wasSubstituted: Whether a substitution was or was not performed on the dispense
    :param CodeableConcept type: Code signifying whether a different drug was dispensed from what was prescribed
    :param CodeableConcept reason: Why was substitution made
    :param Reference responsibleParty: Who is responsible for the substitution
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
        "responsibleParty": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        wasSubstituted: "bool" = None,
        type: "CodeableConcept" = None,
        reason: list["CodeableConcept"] = None,
        responsibleParty: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.wasSubstituted = wasSubstituted
        self.type = type
        self.reason = reason or []
        self.responsibleParty = responsibleParty or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationDispense":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationDispense":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationDispense(DomainResource):
    """Indicates that a medication product is to be or has been dispensed for a named person/patient.  This includes a description of the medication product (supply) provided and the instructions for administering the medication.  The medication dispense is the result of a pharmacy system responding to a medication order.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External identifier
    :param Reference partOf: Event that dispense is part of
    :param str status: preparation | in-progress | cancelled | on-hold | completed | entered-in-error | stopped | declined | unknown
    :param CodeableConcept statusReasonCodeableConcept: Why a dispense was not performed
    :param Reference statusReasonReference: Why a dispense was not performed
    :param CodeableConcept category: Type of medication dispense
    :param CodeableConcept medicationCodeableConcept: What medication was supplied
    :param Reference medicationReference: What medication was supplied
    :param Reference subject: Who the dispense is for
    :param Reference context: Encounter / Episode associated with event
    :param Reference supportingInformation: Information that supports the dispensing of the medication
    :param Performer performer: Who performed event
    :param Reference location: Where the dispense occurred
    :param Reference authorizingPrescription: Medication order that authorizes the dispense
    :param CodeableConcept type: Trial fill, partial fill, emergency fill, etc.
    :param Quantity quantity: Amount dispensed
    :param Quantity daysSupply: Amount of medication expressed as a timing amount
    :param str whenPrepared: When product was packaged and reviewed
    :param str whenHandedOver: When product was given out
    :param Reference destination: Where the medication was sent
    :param Reference receiver: Who collected the medication
    :param Annotation note: Information about the dispense
    :param Dosage dosageInstruction: How the medication is to be used by the patient or administered by the caregiver
    :param Substitution substitution: Whether a substitution was performed on the dispense
    :param Reference detectedIssue: Clinical issue with action
    :param Reference eventHistory: A list of relevant lifecycle events
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReasonCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "statusReasonReference": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationReference": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
        "performer": {"class_name": "Performer", "is_contained": True},
        "location": {"class_name": "Reference", "is_contained": False},
        "authorizingPrescription": {"class_name": "Reference", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "daysSupply": {"class_name": "Quantity", "is_contained": False},
        "destination": {"class_name": "Reference", "is_contained": False},
        "receiver": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "dosageInstruction": {"class_name": "Dosage", "is_contained": False},
        "substitution": {"class_name": "Substitution", "is_contained": True},
        "detectedIssue": {"class_name": "Reference", "is_contained": False},
        "eventHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReasonCodeableConcept: "CodeableConcept" = None,
        statusReasonReference: "Reference" = None,
        category: "CodeableConcept" = None,
        medicationCodeableConcept: "CodeableConcept" = None,
        medicationReference: "Reference" = None,
        subject: "Reference" = None,
        context: "Reference" = None,
        supportingInformation: list["Reference"] = None,
        performer: list["Performer"] = None,
        location: "Reference" = None,
        authorizingPrescription: list["Reference"] = None,
        type: "CodeableConcept" = None,
        quantity: "Quantity" = None,
        daysSupply: "Quantity" = None,
        whenPrepared: "str" = None,
        whenHandedOver: "str" = None,
        destination: "Reference" = None,
        receiver: list["Reference"] = None,
        note: list["Annotation"] = None,
        dosageInstruction: list["Dosage"] = None,
        substitution: "Substitution" = None,
        detectedIssue: list["Reference"] = None,
        eventHistory: list["Reference"] = None,
    ):

        self.resourceType = "MedicationDispense"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.partOf = partOf or []
        self.status = status
        self.statusReasonCodeableConcept = statusReasonCodeableConcept
        self.statusReasonReference = statusReasonReference
        self.category = category
        self.medicationCodeableConcept = medicationCodeableConcept
        self.medicationReference = medicationReference
        self.subject = subject
        self.context = context
        self.supportingInformation = supportingInformation or []
        self.performer = performer or []
        self.location = location
        self.authorizingPrescription = authorizingPrescription or []
        self.type = type
        self.quantity = quantity
        self.daysSupply = daysSupply
        self.whenPrepared = whenPrepared
        self.whenHandedOver = whenHandedOver
        self.destination = destination
        self.receiver = receiver or []
        self.note = note or []
        self.dosageInstruction = dosageInstruction or []
        self.substitution = substitution
        self.detectedIssue = detectedIssue or []
        self.eventHistory = eventHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationDispense":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationDispense":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for StructureMap. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Address import *
from fhirmodels.R4B.Age import *
from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.Attachment import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.ContactPoint import *
from fhirmodels.R4B.Contributor import *
from fhirmodels.R4B.Count import *
from fhirmodels.R4B.DataRequirement import *
from fhirmodels.R4B.Distance import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Dosage import *
from fhirmodels.R4B.Duration import *
from fhirmodels.R4B.Expression import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.HumanName import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Money import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.ParameterDefinition import *
from fhirmodels.R4B.Period import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Range import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.RelatedArtifact import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.SampledData import *
from fhirmodels.R4B.Signature import *
from fhirmodels.R4B.Timing import *
from fhirmodels.R4B.TriggerDefinition import *
from fhirmodels.R4B.UsageContext import *


class Structure(FhirBaseModel):
    """A structure definition used by this map. The structure definition may describe instances that are converted, or the instances that are produced.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str url: Canonical reference to structure definition
    :param str mode: source | queried | target | produced
    :param str alias: Name for type in this map
    :param str documentation: Documentation on use of structure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        mode: "str" = None,
        alias: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.mode = mode
        self.alias = alias
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Input(FhirBaseModel):
    """A name assigned to an instance of data. The instance must be provided when the mapping is invoked.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name for this instance of data
    :param str type: Type for this instance of data
    :param str mode: source | target
    :param str documentation: Documentation for this instance of data
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        type: "str" = None,
        mode: "str" = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.type = type
        self.mode = mode
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Source(FhirBaseModel):
    """Source inputs to the mapping.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str context: Type or variable this rule applies to
    :param int min: Specified minimum cardinality
    :param str max: Specified maximum cardinality (number or *)
    :param str type: Rule only applies if source has this type
    :param str defaultValueBase64Binary: Default value if no value exists
    :param bool defaultValueBoolean: Default value if no value exists
    :param str defaultValueCanonical: Default value if no value exists
    :param str defaultValueCode: Default value if no value exists
    :param str defaultValueDate: Default value if no value exists
    :param str defaultValueDateTime: Default value if no value exists
    :param float defaultValueDecimal: Default value if no value exists
    :param str defaultValueId: Default value if no value exists
    :param str defaultValueInstant: Default value if no value exists
    :param int defaultValueInteger: Default value if no value exists
    :param str defaultValueMarkdown: Default value if no value exists
    :param str defaultValueOid: Default value if no value exists
    :param int defaultValuePositiveInt: Default value if no value exists
    :param str defaultValueString: Default value if no value exists
    :param str defaultValueTime: Default value if no value exists
    :param int defaultValueUnsignedInt: Default value if no value exists
    :param str defaultValueUri: Default value if no value exists
    :param str defaultValueUrl: Default value if no value exists
    :param str defaultValueUuid: Default value if no value exists
    :param Address defaultValueAddress: Default value if no value exists
    :param Age defaultValueAge: Default value if no value exists
    :param Annotation defaultValueAnnotation: Default value if no value exists
    :param Attachment defaultValueAttachment: Default value if no value exists
    :param CodeableConcept defaultValueCodeableConcept: Default value if no value exists
    :param Coding defaultValueCoding: Default value if no value exists
    :param ContactPoint defaultValueContactPoint: Default value if no value exists
    :param Count defaultValueCount: Default value if no value exists
    :param Distance defaultValueDistance: Default value if no value exists
    :param Duration defaultValueDuration: Default value if no value exists
    :param HumanName defaultValueHumanName: Default value if no value exists
    :param Identifier defaultValueIdentifier: Default value if no value exists
    :param Money defaultValueMoney: Default value if no value exists
    :param Period defaultValuePeriod: Default value if no value exists
    :param Quantity defaultValueQuantity: Default value if no value exists
    :param Range defaultValueRange: Default value if no value exists
    :param Ratio defaultValueRatio: Default value if no value exists
    :param Reference defaultValueReference: Default value if no value exists
    :param SampledData defaultValueSampledData: Default value if no value exists
    :param Signature defaultValueSignature: Default value if no value exists
    :param Timing defaultValueTiming: Default value if no value exists
    :param ContactDetail defaultValueContactDetail: Default value if no value exists
    :param Contributor defaultValueContributor: Default value if no value exists
    :param DataRequirement defaultValueDataRequirement: Default value if no value exists
    :param Expression defaultValueExpression: Default value if no value exists
    :param ParameterDefinition defaultValueParameterDefinition: Default value if no value exists
    :param RelatedArtifact defaultValueRelatedArtifact: Default value if no value exists
    :param TriggerDefinition defaultValueTriggerDefinition: Default value if no value exists
    :param UsageContext defaultValueUsageContext: Default value if no value exists
    :param Dosage defaultValueDosage: Default value if no value exists
    :param Meta defaultValueMeta: Default value if no value exists
    :param str element: Optional field for this source
    :param str listMode: first | not_first | last | not_last | only_one
    :param str variable: Named context for field, if a field is specified
    :param str condition: FHIRPath expression  - must be true or the rule does not apply
    :param str check: FHIRPath expression  - must be true or the mapping engine throws an error instead of completing
    :param str logMessage: Message to put in log if source exists (FHIRPath)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "defaultValueAddress": {"class_name": "Address", "is_contained": False},
        "defaultValueAge": {"class_name": "Age", "is_contained": False},
        "defaultValueAnnotation": {"class_name": "Annotation", "is_contained": False},
        "defaultValueAttachment": {"class_name": "Attachment", "is_contained": False},
        "defaultValueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "defaultValueCoding": {"class_name": "Coding", "is_contained": False},
        "defaultValueContactPoint": {
            "class_name": "ContactPoint",
            "is_contained": False,
        },
        "defaultValueCount": {"class_name": "Count", "is_contained": False},
        "defaultValueDistance": {"class_name": "Distance", "is_contained": False},
        "defaultValueDuration": {"class_name": "Duration", "is_contained": False},
        "defaultValueHumanName": {"class_name": "HumanName", "is_contained": False},
        "defaultValueIdentifier": {"class_name": "Identifier", "is_contained": False},
        "defaultValueMoney": {"class_name": "Money", "is_contained": False},
        "defaultValuePeriod": {"class_name": "Period", "is_contained": False},
        "defaultValueQuantity": {"class_name": "Quantity", "is_contained": False},
        "defaultValueRange": {"class_name": "Range", "is_contained": False},
        "defaultValueRatio": {"class_name": "Ratio", "is_contained": False},
        "defaultValueReference": {"class_name": "Reference", "is_contained": False},
        "defaultValueSampledData": {"class_name": "SampledData", "is_contained": False},
        "defaultValueSignature": {"class_name": "Signature", "is_contained": False},
        "defaultValueTiming": {"class_name": "Timing", "is_contained": False},
        "defaultValueContactDetail": {
            "class_name": "ContactDetail",
            "is_contained": False,
        },
        "defaultValueContributor": {"class_name": "Contributor", "is_contained": False},
        "defaultValueDataRequirement": {
            "class_name": "DataRequirement",
            "is_contained": False,
        },
        "defaultValueExpression": {"class_name": "Expression", "is_contained": False},
        "defaultValueParameterDefinition": {
            "class_name": "ParameterDefinition",
            "is_contained": False,
        },
        "defaultValueRelatedArtifact": {
            "class_name": "RelatedArtifact",
            "is_contained": False,
        },
        "defaultValueTriggerDefinition": {
            "class_name": "TriggerDefinition",
            "is_contained": False,
        },
        "defaultValueUsageContext": {
            "class_name": "UsageContext",
            "is_contained": False,
        },
        "defaultValueDosage": {"class_name": "Dosage", "is_contained": False},
        "defaultValueMeta": {"class_name": "Meta", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        context: "str" = None,
        min: "int" = None,
        max: "str" = None,
        type: "str" = None,
        defaultValueBase64Binary: "str" = None,
        defaultValueBoolean: "bool" = None,
        defaultValueCanonical: "str" = None,
        defaultValueCode: "str" = None,
        defaultValueDate: "str" = None,
        defaultValueDateTime: "str" = None,
        defaultValueDecimal: "float" = None,
        defaultValueId: "str" = None,
        defaultValueInstant: "str" = None,
        defaultValueInteger: "int" = None,
        defaultValueMarkdown: "str" = None,
        defaultValueOid: "str" = None,
        defaultValuePositiveInt: "int" = None,
        defaultValueString: "str" = None,
        defaultValueTime: "str" = None,
        defaultValueUnsignedInt: "int" = None,
        defaultValueUri: "str" = None,
        defaultValueUrl: "str" = None,
        defaultValueUuid: "str" = None,
        defaultValueAddress: "Address" = None,
        defaultValueAge: "Age" = None,
        defaultValueAnnotation: "Annotation" = None,
        defaultValueAttachment: "Attachment" = None,
        defaultValueCodeableConcept: "CodeableConcept" = None,
        defaultValueCoding: "Coding" = None,
        defaultValueContactPoint: "ContactPoint" = None,
        defaultValueCount: "Count" = None,
        defaultValueDistance: "Distance" = None,
        defaultValueDuration: "Duration" = None,
        defaultValueHumanName: "HumanName" = None,
        defaultValueIdentifier: "Identifier" = None,
        defaultValueMoney: "Money" = None,
        defaultValuePeriod: "Period" = None,
        defaultValueQuantity: "Quantity" = None,
        defaultValueRange: "Range" = None,
        defaultValueRatio: "Ratio" = None,
        defaultValueReference: "Reference" = None,
        defaultValueSampledData: "SampledData" = None,
        defaultValueSignature: "Signature" = None,
        defaultValueTiming: "Timing" = None,
        defaultValueContactDetail: "ContactDetail" = None,
        defaultValueContributor: "Contributor" = None,
        defaultValueDataRequirement: "DataRequirement" = None,
        defaultValueExpression: "Expression" = None,
        defaultValueParameterDefinition: "ParameterDefinition" = None,
        defaultValueRelatedArtifact: "RelatedArtifact" = None,
        defaultValueTriggerDefinition: "TriggerDefinition" = None,
        defaultValueUsageContext: "UsageContext" = None,
        defaultValueDosage: "Dosage" = None,
        defaultValueMeta: "Meta" = None,
        element: "str" = None,
        listMode: "str" = None,
        variable: "str" = None,
        condition: "str" = None,
        check: "str" = None,
        logMessage: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.context = context
        self.min = min
        self.max = max
        self.type = type
        self.defaultValueBase64Binary = defaultValueBase64Binary
        self.defaultValueBoolean = defaultValueBoolean
        self.defaultValueCanonical = defaultValueCanonical
        self.defaultValueCode = defaultValueCode
        self.defaultValueDate = defaultValueDate
        self.defaultValueDateTime = defaultValueDateTime
        self.defaultValueDecimal = defaultValueDecimal
        self.defaultValueId = defaultValueId
        self.defaultValueInstant = defaultValueInstant
        self.defaultValueInteger = defaultValueInteger
        self.defaultValueMarkdown = defaultValueMarkdown
        self.defaultValueOid = defaultValueOid
        self.defaultValuePositiveInt = defaultValuePositiveInt
        self.defaultValueString = defaultValueString
        self.defaultValueTime = defaultValueTime
        self.defaultValueUnsignedInt = defaultValueUnsignedInt
        self.defaultValueUri = defaultValueUri
        self.defaultValueUrl = defaultValueUrl
        self.defaultValueUuid = defaultValueUuid
        self.defaultValueAddress = defaultValueAddress
        self.defaultValueAge = defaultValueAge
        self.defaultValueAnnotation = defaultValueAnnotation
        self.defaultValueAttachment = defaultValueAttachment
        self.defaultValueCodeableConcept = defaultValueCodeableConcept
        self.defaultValueCoding = defaultValueCoding
        self.defaultValueContactPoint = defaultValueContactPoint
        self.defaultValueCount = defaultValueCount
        self.defaultValueDistance = defaultValueDistance
        self.defaultValueDuration = defaultValueDuration
        self.defaultValueHumanName = defaultValueHumanName
        self.defaultValueIdentifier = defaultValueIdentifier
        self.defaultValueMoney = defaultValueMoney
        self.defaultValuePeriod = defaultValuePeriod
        self.defaultValueQuantity = defaultValueQuantity
        self.defaultValueRange = defaultValueRange
        self.defaultValueRatio = defaultValueRatio
        self.defaultValueReference = defaultValueReference
        self.defaultValueSampledData = defaultValueSampledData
        self.defaultValueSignature = defaultValueSignature
        self.defaultValueTiming = defaultValueTiming
        self.defaultValueContactDetail = defaultValueContactDetail
        self.defaultValueContributor = defaultValueContributor
        self.defaultValueDataRequirement = defaultValueDataRequirement
        self.defaultValueExpression = defaultValueExpression
        self.defaultValueParameterDefinition = defaultValueParameterDefinition
        self.defaultValueRelatedArtifact = defaultValueRelatedArtifact
        self.defaultValueTriggerDefinition = defaultValueTriggerDefinition
        self.defaultValueUsageContext = defaultValueUsageContext
        self.defaultValueDosage = defaultValueDosage
        self.defaultValueMeta = defaultValueMeta
        self.element = element
        self.listMode = listMode
        self.variable = variable
        self.condition = condition
        self.check = check
        self.logMessage = logMessage

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Parameter(FhirBaseModel):
    """Parameters to the transform.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str valueId: Parameter value - variable or literal
    :param str valueString: Parameter value - variable or literal
    :param bool valueBoolean: Parameter value - variable or literal
    :param int valueInteger: Parameter value - variable or literal
    :param float valueDecimal: Parameter value - variable or literal
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        valueId: "str" = None,
        valueString: "str" = None,
        valueBoolean: "bool" = None,
        valueInteger: "int" = None,
        valueDecimal: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.valueId = valueId
        self.valueString = valueString
        self.valueBoolean = valueBoolean
        self.valueInteger = valueInteger
        self.valueDecimal = valueDecimal

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Target(FhirBaseModel):
    """Content to create because of this mapping rule.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str context: Type or variable this rule applies to
    :param str contextType: type | variable
    :param str element: Field to create in the context
    :param str variable: Named context for field, if desired, and a field is specified
    :param str listMode: first | share | last | collate
    :param str listRuleId: Internal rule reference for shared list items
    :param str transform: create | copy +
    :param Parameter parameter: Parameters to the transform
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "parameter": {"class_name": "Parameter", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        context: "str" = None,
        contextType: "str" = None,
        element: "str" = None,
        variable: "str" = None,
        listMode: list["str"] = None,
        listRuleId: "str" = None,
        transform: "str" = None,
        parameter: list["Parameter"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.context = context
        self.contextType = contextType
        self.element = element
        self.variable = variable
        self.listMode = listMode or []
        self.listRuleId = listRuleId
        self.transform = transform
        self.parameter = parameter or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dependent(FhirBaseModel):
    """Which other rules to apply in the context of this rule.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name of a rule or group to apply
    :param str variable: Variable to pass to the rule or group
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        variable: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.variable = variable or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Rule(FhirBaseModel):
    """Transform Rule from source to target.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Name of the rule for internal references
    :param Source source: Source inputs to the mapping
    :param Target target: Content to create because of this mapping rule
    :param Rule rule: Rules contained in this rule
    :param Dependent dependent: Which other rules to apply in the context of this rule
    :param str documentation: Documentation for this instance of data
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "source": {"class_name": "Source", "is_contained": True},
        "target": {"class_name": "Target", "is_contained": True},
        "rule": {"class_name": "Rule", "is_contained": True},
        "dependent": {"class_name": "Dependent", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        source: list["Source"] = None,
        target: list["Target"] = None,
        rule: list["Rule"] = None,
        dependent: list["Dependent"] = None,
        documentation: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.source = source or []
        self.target = target or []
        self.rule = rule or []
        self.dependent = dependent or []
        self.documentation = documentation

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Group(FhirBaseModel):
    """Organizes the mapping into manageable chunks for human review/ease of maintenance.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Human-readable label
    :param str extends: Another group that this group adds rules to
    :param str typeMode: none | types | type-and-types
    :param str documentation: Additional description/explanation for group
    :param Input input: Named instance provided when invoking the map
    :param Rule rule: Transform Rule from source to target
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "input": {"class_name": "Input", "is_contained": True},
        "rule": {"class_name": "Rule", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        extends: "str" = None,
        typeMode: "str" = None,
        documentation: "str" = None,
        input: list["Input"] = None,
        rule: list["Rule"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.extends = extends
        self.typeMode = typeMode
        self.documentation = documentation
        self.input = input or []
        self.rule = rule or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StructureMap(DomainResource):
    """A Map of relationships between 2 structures that can be used to transform data.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this structure map, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the structure map
    :param str version: Business version of the structure map
    :param str name: Name for this structure map (computer friendly)
    :param str title: Name for this structure map (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the structure map
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for structure map (if applicable)
    :param str purpose: Why this structure map is defined
    :param str copyright: Use and/or publishing restrictions
    :param Structure structure: Structure Definition used by this map
    :param str _import: Other maps used by this map (canonical URLs)
    :param Group group: Named sections for reader convenience
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "structure": {"class_name": "Structure", "is_contained": True},
        "group": {"class_name": "Group", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        structure: list["Structure"] = None,
        _import: list["str"] = None,
        group: list["Group"] = None,
    ):

        self.resourceType = "StructureMap"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.structure = structure or []
        self._import = _import or []
        self.group = group or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureMap":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureMap":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for StructureDefinition. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.Coding import *
from fhirmodels.R4B.ContactDetail import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.ElementDefinition import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.UsageContext import *


class Mapping(FhirBaseModel):
    """An external specification that the content is mapped to.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str identity: Internal id when this mapping is used
    :param str uri: Identifies what this mapping refers to
    :param str name: Names what this mapping refers to
    :param str comment: Versions, Issues, Scope limitations etc.
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identity: "str" = None,
        uri: "str" = None,
        name: "str" = None,
        comment: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identity = identity
        self.uri = uri
        self.name = name
        self.comment = comment

    @classmethod
    def from_dict(cls, data: dict) -> "StructureDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Context(FhirBaseModel):
    """Identifies the types of resource or data type elements to which the extension can be applied.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: fhirpath | element | extension
    :param str expression: Where the extension can be used in instances
    :param str contextInvariant: FHIRPath invariants - when the extension can be used
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        expression: "str" = None,
        contextInvariant: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.expression = expression
        self.contextInvariant = contextInvariant or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Snapshot(FhirBaseModel):
    """A snapshot view is expressed in a standalone form that can be used and interpreted without considering the base StructureDefinition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param ElementDefinition element: Definition of elements in the resource (if no StructureDefinition)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "element": {"class_name": "ElementDefinition", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        element: list["ElementDefinition"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.element = element or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Differential(FhirBaseModel):
    """A differential view is expressed relative to the base StructureDefinition - a statement of differences that it applies.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param ElementDefinition element: Definition of elements in the resource (if no StructureDefinition)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "element": {"class_name": "ElementDefinition", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        element: list["ElementDefinition"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.element = element or []

    @classmethod
    def from_dict(cls, data: dict) -> "StructureDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class StructureDefinition(DomainResource):
    """A definition of a FHIR structure. This resource is used to describe the underlying resources, data types defined in FHIR, and also for describing extensions and constraints on resources and data types.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this structure definition, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the structure definition
    :param str version: Business version of the structure definition
    :param str name: Name for this structure definition (computer friendly)
    :param str title: Name for this structure definition (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the structure definition
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for structure definition (if applicable)
    :param str purpose: Why this structure definition is defined
    :param str copyright: Use and/or publishing restrictions
    :param Coding keyword: Assist with indexing and finding
    :param str fhirVersion: FHIR Version this StructureDefinition targets
    :param Mapping mapping: External specification that the content is mapped to
    :param str kind: primitive-type | complex-type | resource | logical
    :param bool abstract: Whether the structure is abstract
    :param Context context: If an extension, where it can be used in instances
    :param str type: Type defined or constrained by this structure
    :param str baseDefinition: Definition that this type is constrained/specialized from
    :param str derivation: specialization | constraint - How relates to base definition
    :param Snapshot snapshot: Snapshot view of the structure
    :param Differential differential: Differential view of the structure
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "keyword": {"class_name": "Coding", "is_contained": False},
        "mapping": {"class_name": "Mapping", "is_contained": True},
        "context": {"class_name": "Context", "is_contained": True},
        "snapshot": {"class_name": "Snapshot", "is_contained": True},
        "differential": {"class_name": "Differential", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        keyword: list["Coding"] = None,
        fhirVersion: "str" = None,
        mapping: list["Mapping"] = None,
        kind: "str" = None,
        abstract: "bool" = None,
        context: list["Context"] = None,
        type: "str" = None,
        baseDefinition: "str" = None,
        derivation: "str" = None,
        snapshot: "Snapshot" = None,
        differential: "Differential" = None,
    ):

        self.resourceType = "StructureDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.keyword = keyword or []
        self.fhirVersion = fhirVersion
        self.mapping = mapping or []
        self.kind = kind
        self.abstract = abstract
        self.context = context or []
        self.type = type
        self.baseDefinition = baseDefinition
        self.derivation = derivation
        self.snapshot = snapshot
        self.differential = differential

    @classmethod
    def from_dict(cls, data: dict) -> "StructureDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "StructureDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



from .Account import Account
from .ActivityDefinition import ActivityDefinition
from .Address import Address
from .AdministrableProductDefinition import AdministrableProductDefinition
from .AdverseEvent import AdverseEvent
from .Age import Age
from .AllergyIntolerance import AllergyIntolerance
from .Annotation import Annotation
from .Appointment import Appointment
from .AppointmentResponse import AppointmentResponse
from .Attachment import Attachment
from .AuditEvent import AuditEvent
from .BackboneElement import BackboneElement
from .Basic import Basic
from .Binary import Binary
from .BiologicallyDerivedProduct import BiologicallyDerivedProduct
from .BodyStructure import BodyStructure
from .Bundle import Bundle
from .CapabilityStatement import CapabilityStatement
from .CarePlan import CarePlan
from .CareTeam import CareTeam
from .CatalogEntry import CatalogEntry
from .ChargeItem import ChargeItem
from .ChargeItemDefinition import ChargeItemDefinition
from .Citation import Citation
from .Claim import Claim
from .ClaimResponse import ClaimResponse
from .ClinicalImpression import ClinicalImpression
from .ClinicalUseDefinition import ClinicalUseDefinition
from .CodeableConcept import CodeableConcept
from .CodeableReference import CodeableReference
from .CodeSystem import CodeSystem
from .Coding import Coding
from .Communication import Communication
from .CommunicationRequest import CommunicationRequest
from .CompartmentDefinition import CompartmentDefinition
from .Composition import Composition
from .ConceptMap import ConceptMap
from .Condition import Condition
from .Consent import Consent
from .ContactDetail import ContactDetail
from .ContactPoint import ContactPoint
from .Contract import Contract
from .Contributor import Contributor
from .Count import Count
from .Coverage import Coverage
from .CoverageEligibilityRequest import CoverageEligibilityRequest
from .CoverageEligibilityResponse import CoverageEligibilityResponse
from .DataRequirement import DataRequirement
from .DataType import DataType
from .Definition import Definition
from .DetectedIssue import DetectedIssue
from .Device import Device
from .DeviceDefinition import DeviceDefinition
from .DeviceMetric import DeviceMetric
from .DeviceRequest import DeviceRequest
from .DeviceUseStatement import DeviceUseStatement
from .DiagnosticReport import DiagnosticReport
from .Distance import Distance
from .DocumentManifest import DocumentManifest
from .DocumentReference import DocumentReference
from .DomainResource import DomainResource
from .Dosage import Dosage
from .Duration import Duration
from .Element import Element
from .ElementDefinition import ElementDefinition
from .Encounter import Encounter
from .Endpoint import Endpoint
from .EnrollmentRequest import EnrollmentRequest
from .EnrollmentResponse import EnrollmentResponse
from .EpisodeOfCare import EpisodeOfCare
from .Event import Event
from .EventDefinition import EventDefinition
from .Evidence import Evidence
from .EvidenceReport import EvidenceReport
from .EvidenceVariable import EvidenceVariable
from .ExampleScenario import ExampleScenario
from .ExplanationOfBenefit import ExplanationOfBenefit
from .Expression import Expression
from .Extension import Extension
from .FamilyMemberHistory import FamilyMemberHistory
from .FiveWs import FiveWs
from .Flag import Flag
from .Goal import Goal
from .GraphDefinition import GraphDefinition
from .Group import Group
from .GuidanceResponse import GuidanceResponse
from .HealthcareService import HealthcareService
from .HumanName import HumanName
from .Identifier import Identifier
from .ImagingStudy import ImagingStudy
from .Immunization import Immunization
from .ImmunizationEvaluation import ImmunizationEvaluation
from .ImmunizationRecommendation import ImmunizationRecommendation
from .ImplementationGuide import ImplementationGuide
from .Ingredient import Ingredient
from .InsurancePlan import InsurancePlan
from .Invoice import Invoice
from .Library import Library
from .Linkage import Linkage
from .List import List
from .Location import Location
from .ManufacturedItemDefinition import ManufacturedItemDefinition
from .MarketingStatus import MarketingStatus
from .Measure import Measure
from .MeasureReport import MeasureReport
from .Media import Media
from .Medication import Medication
from .MedicationAdministration import MedicationAdministration
from .MedicationDispense import MedicationDispense
from .MedicationKnowledge import MedicationKnowledge
from .MedicationRequest import MedicationRequest
from .MedicationStatement import MedicationStatement
from .MedicinalProductDefinition import MedicinalProductDefinition
from .MessageDefinition import MessageDefinition
from .MessageHeader import MessageHeader
from .Meta import Meta
from .MolecularSequence import MolecularSequence
from .Money import Money
from .NamingSystem import NamingSystem
from .Narrative import Narrative
from .NutritionOrder import NutritionOrder
from .NutritionProduct import NutritionProduct
from .Observation import Observation
from .ObservationDefinition import ObservationDefinition
from .OperationDefinition import OperationDefinition
from .OperationOutcome import OperationOutcome
from .Organization import Organization
from .OrganizationAffiliation import OrganizationAffiliation
from .PackagedProductDefinition import PackagedProductDefinition
from .ParameterDefinition import ParameterDefinition
from .Parameters import Parameters
from .Patient import Patient
from .PaymentNotice import PaymentNotice
from .PaymentReconciliation import PaymentReconciliation
from .Period import Period
from .Person import Person
from .PlanDefinition import PlanDefinition
from .Population import Population
from .Practitioner import Practitioner
from .PractitionerRole import PractitionerRole
from .Procedure import Procedure
from .ProdCharacteristic import ProdCharacteristic
from .ProductShelfLife import ProductShelfLife
from .Provenance import Provenance
from .Quantity import Quantity
from .Questionnaire import Questionnaire
from .QuestionnaireResponse import QuestionnaireResponse
from .Range import Range
from .Ratio import Ratio
from .RatioRange import RatioRange
from .Reference import Reference
from .RegulatedAuthorization import RegulatedAuthorization
from .RelatedArtifact import RelatedArtifact
from .RelatedPerson import RelatedPerson
from .Request import Request
from .RequestGroup import RequestGroup
from .ResearchDefinition import ResearchDefinition
from .ResearchElementDefinition import ResearchElementDefinition
from .ResearchStudy import ResearchStudy
from .ResearchSubject import ResearchSubject
from .Resource import Resource
from .RiskAssessment import RiskAssessment
from .SampledData import SampledData
from .Schedule import Schedule
from .SearchParameter import SearchParameter
from .ServiceRequest import ServiceRequest
from .Signature import Signature
from .Slot import Slot
from .Specimen import Specimen
from .SpecimenDefinition import SpecimenDefinition
from .StructureDefinition import StructureDefinition
from .StructureMap import StructureMap
from .Subscription import Subscription
from .SubscriptionStatus import SubscriptionStatus
from .SubscriptionTopic import SubscriptionTopic
from .Substance import Substance
from .SubstanceDefinition import SubstanceDefinition
from .SupplyDelivery import SupplyDelivery
from .SupplyRequest import SupplyRequest
from .Task import Task
from .TerminologyCapabilities import TerminologyCapabilities
from .TestReport import TestReport
from .TestScript import TestScript
from .Timing import Timing
from .TriggerDefinition import TriggerDefinition
from .UsageContext import UsageContext
from .ValueSet import ValueSet
from .VerificationResult import VerificationResult
from .VisionPrescription import VisionPrescription



"""
Generated class for EncounterHistory. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Location(FhirBaseModel):
    """The location of the patient at this point in the encounter, the multiple cardinality permits de-normalizing the levels of the location hierarchy, such as site/ward/room/bed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference location: Location the encounter takes place
    :param CodeableConcept form: The physical type of the location (usually the level in the location hierarchy - bed, room, ward, virtual etc.)
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "location": {"class_name": "Reference", "is_contained": False},
        "form": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        location: "Reference" = None,
        form: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.location = location
        self.form = form

    @classmethod
    def from_dict(cls, data: dict) -> "EncounterHistory":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EncounterHistory":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EncounterHistory(DomainResource):
    """A record of significant events/milestones key data throughout the history of an Encounter
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Reference encounter: The Encounter associated with this set of historic values
    :param Identifier identifier: Identifier(s) by which this encounter is known
    :param str status: planned | in-progress | on-hold | discharged | completed | cancelled | discontinued | entered-in-error | unknown
    :param CodeableConcept _class: Classification of patient encounter
    :param CodeableConcept type: Specific type of encounter
    :param CodeableReference serviceType: Specific type of service
    :param Reference subject: The patient or group related to this encounter
    :param CodeableConcept subjectStatus: The current status of the subject in relation to the Encounter
    :param Period actualPeriod: The actual start and end time associated with this set of values associated with the encounter
    :param str plannedStartDate: The planned start date/time (or admission date) of the encounter
    :param str plannedEndDate: The planned end date/time (or discharge date) of the encounter
    :param Duration length: Actual quantity of time the encounter lasted (less time absent)
    :param Location location: Location of the patient at this point in the encounter
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "_class": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "serviceType": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "subjectStatus": {"class_name": "CodeableConcept", "is_contained": False},
        "actualPeriod": {"class_name": "Period", "is_contained": False},
        "length": {"class_name": "Duration", "is_contained": False},
        "location": {"class_name": "Location", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        encounter: "Reference" = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        _class: "CodeableConcept" = None,
        type: list["CodeableConcept"] = None,
        serviceType: list["CodeableReference"] = None,
        subject: "Reference" = None,
        subjectStatus: "CodeableConcept" = None,
        actualPeriod: "Period" = None,
        plannedStartDate: "str" = None,
        plannedEndDate: "str" = None,
        length: "Duration" = None,
        location: list["Location"] = None,
    ):

        self.resourceType = "EncounterHistory"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.encounter = encounter
        self.identifier = identifier or []
        self.status = status
        self._class = _class
        self.type = type or []
        self.serviceType = serviceType or []
        self.subject = subject
        self.subjectStatus = subjectStatus
        self.actualPeriod = actualPeriod
        self.plannedStartDate = plannedStartDate
        self.plannedEndDate = plannedEndDate
        self.length = length
        self.location = location or []

    @classmethod
    def from_dict(cls, data: dict) -> "EncounterHistory":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EncounterHistory":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for NutritionOrder. 
Time: 2024-06-14 18:37:49
"""

from fhirmodels.R4B.Annotation import *
from fhirmodels.R4B.BackboneElement import *
from fhirmodels.R4B.CodeableConcept import *
from fhirmodels.R4B.DomainResource import *
from fhirmodels.R4B.Extension import *
from fhirmodels.R4B.Identifier import *
from fhirmodels.R4B.Meta import *
from fhirmodels.R4B.Narrative import *
from fhirmodels.R4B.Quantity import *
from fhirmodels.R4B.Ratio import *
from fhirmodels.R4B.Reference import *
from fhirmodels.R4B.Resource import *
from fhirmodels.R4B.Timing import *


class Nutrient(FhirBaseModel):
    """Class that defines the quantity and type of nutrient modifications (for example carbohydrate, fiber or sodium) required for the oral diet.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept modifier: Type of nutrient that is being modified
    :param Quantity amount: Quantity of the specified nutrient
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "amount": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        modifier: "CodeableConcept" = None,
        amount: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.modifier = modifier
        self.amount = amount

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Texture(FhirBaseModel):
    """Class that describes any texture modifications required for the patient to safely consume various types of solid foods.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept modifier: Code to indicate how to alter the texture of the foods, e.g. pureed
    :param CodeableConcept foodType: Concepts that are used to identify an entity that is ingested for nutritional purposes
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "modifier": {"class_name": "CodeableConcept", "is_contained": False},
        "foodType": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        modifier: "CodeableConcept" = None,
        foodType: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.modifier = modifier
        self.foodType = foodType

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class OralDiet(FhirBaseModel):
    """Diet given orally in contrast to enteral (tube) feeding.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of oral diet or diet restrictions that describe what can be consumed orally
    :param Timing schedule: Scheduled frequency of diet
    :param Nutrient nutrient: Required  nutrient modifications
    :param Texture texture: Required  texture modifications
    :param CodeableConcept fluidConsistencyType: The required consistency of fluids and liquids provided to the patient
    :param str instruction: Instructions or additional information about the oral diet
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "schedule": {"class_name": "Timing", "is_contained": False},
        "nutrient": {"class_name": "Nutrient", "is_contained": True},
        "texture": {"class_name": "Texture", "is_contained": True},
        "fluidConsistencyType": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: list["CodeableConcept"] = None,
        schedule: list["Timing"] = None,
        nutrient: list["Nutrient"] = None,
        texture: list["Texture"] = None,
        fluidConsistencyType: list["CodeableConcept"] = None,
        instruction: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type or []
        self.schedule = schedule or []
        self.nutrient = nutrient or []
        self.texture = texture or []
        self.fluidConsistencyType = fluidConsistencyType or []
        self.instruction = instruction

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Supplement(FhirBaseModel):
    """Oral nutritional products given in order to add further nutritional value to the patient's diet.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of supplement product requested
    :param str productName: Product or brand name of the nutritional supplement
    :param Timing schedule: Scheduled frequency of supplement
    :param Quantity quantity: Amount of the nutritional supplement
    :param str instruction: Instructions or additional information about the oral supplement
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "schedule": {"class_name": "Timing", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        productName: "str" = None,
        schedule: list["Timing"] = None,
        quantity: "Quantity" = None,
        instruction: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.productName = productName
        self.schedule = schedule or []
        self.quantity = quantity
        self.instruction = instruction

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Administration(FhirBaseModel):
    """Formula administration instructions as structured data.  This repeating structure allows for changing the administration rate or volume over time for both bolus and continuous feeding.  An example of this would be an instruction to increase the rate of continuous feeding every 2 hours.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Timing schedule: Scheduled frequency of enteral feeding
    :param Quantity quantity: The volume of formula to provide
    :param Quantity rateQuantity: Speed with which the formula is provided per period of time
    :param Ratio rateRatio: Speed with which the formula is provided per period of time
    :param str administrationInstruction: Formula feeding instructions expressed as text
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "schedule": {"class_name": "Timing", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "rateQuantity": {"class_name": "Quantity", "is_contained": False},
        "rateRatio": {"class_name": "Ratio", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        schedule: "Timing" = None,
        quantity: "Quantity" = None,
        rateQuantity: "Quantity" = None,
        rateRatio: "Ratio" = None,
        administrationInstruction: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.schedule = schedule
        self.quantity = quantity
        self.rateQuantity = rateQuantity
        self.rateRatio = rateRatio
        self.administrationInstruction = administrationInstruction

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EnteralFormula(FhirBaseModel):
    """Feeding provided through the gastrointestinal tract via a tube, catheter, or stoma that delivers nutrition distal to the oral cavity.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept baseFormulaType: Type of enteral or infant formula
    :param str baseFormulaProductName: Product or brand name of the enteral or infant formula
    :param CodeableConcept additiveType: Type of modular component to add to the feeding
    :param str additiveProductName: Product or brand name of the modular additive
    :param Quantity caloricDensity: Amount of energy per specified volume that is required
    :param CodeableConcept routeofAdministration: How the formula should enter the patient's gastrointestinal tract
    :param Administration administration: Formula feeding instruction as structured data
    :param Quantity maxVolumeToDeliver: Upper limit on formula volume per unit of time
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "baseFormulaType": {"class_name": "CodeableConcept", "is_contained": False},
        "additiveType": {"class_name": "CodeableConcept", "is_contained": False},
        "caloricDensity": {"class_name": "Quantity", "is_contained": False},
        "routeofAdministration": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "administration": {"class_name": "Administration", "is_contained": True},
        "maxVolumeToDeliver": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        baseFormulaType: "CodeableConcept" = None,
        baseFormulaProductName: "str" = None,
        additiveType: "CodeableConcept" = None,
        additiveProductName: "str" = None,
        caloricDensity: "Quantity" = None,
        routeofAdministration: "CodeableConcept" = None,
        administration: list["Administration"] = None,
        maxVolumeToDeliver: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.baseFormulaType = baseFormulaType
        self.baseFormulaProductName = baseFormulaProductName
        self.additiveType = additiveType
        self.additiveProductName = additiveProductName
        self.caloricDensity = caloricDensity
        self.routeofAdministration = routeofAdministration
        self.administration = administration or []
        self.maxVolumeToDeliver = maxVolumeToDeliver

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class NutritionOrder(DomainResource):
    """A request to supply a diet, formula feeding (enteral) or oral nutritional supplement to a patient/resident.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Identifiers assigned to this order
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param str instantiates: Instantiates protocol or definition
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param str intent: proposal | plan | directive | order | original-order | reflex-order | filler-order | instance-order | option
    :param Reference patient: The person who requires the diet, formula or nutritional supplement
    :param Reference encounter: The encounter associated with this nutrition order
    :param str dateTime: Date and time the nutrition order was requested
    :param Reference orderer: Who ordered the diet, formula or nutritional supplement
    :param Reference allergyIntolerance: List of the patient's food and nutrition-related allergies and intolerances
    :param CodeableConcept foodPreferenceModifier: Order-specific modifier about the type of food that should be given
    :param CodeableConcept excludeFoodModifier: Order-specific modifier about the type of food that should not be given
    :param OralDiet oralDiet: Oral diet components
    :param Supplement supplement: Supplement components
    :param EnteralFormula enteralFormula: Enteral formula components
    :param Annotation note: Comments
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "patient": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "orderer": {"class_name": "Reference", "is_contained": False},
        "allergyIntolerance": {"class_name": "Reference", "is_contained": False},
        "foodPreferenceModifier": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "excludeFoodModifier": {"class_name": "CodeableConcept", "is_contained": False},
        "oralDiet": {"class_name": "OralDiet", "is_contained": True},
        "supplement": {"class_name": "Supplement", "is_contained": True},
        "enteralFormula": {"class_name": "EnteralFormula", "is_contained": True},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        instantiates: list["str"] = None,
        status: "str" = None,
        intent: "str" = None,
        patient: "Reference" = None,
        encounter: "Reference" = None,
        dateTime: "str" = None,
        orderer: "Reference" = None,
        allergyIntolerance: list["Reference"] = None,
        foodPreferenceModifier: list["CodeableConcept"] = None,
        excludeFoodModifier: list["CodeableConcept"] = None,
        oralDiet: "OralDiet" = None,
        supplement: list["Supplement"] = None,
        enteralFormula: "EnteralFormula" = None,
        note: list["Annotation"] = None,
    ):

        self.resourceType = "NutritionOrder"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.instantiates = instantiates or []
        self.status = status
        self.intent = intent
        self.patient = patient
        self.encounter = encounter
        self.dateTime = dateTime
        self.orderer = orderer
        self.allergyIntolerance = allergyIntolerance or []
        self.foodPreferenceModifier = foodPreferenceModifier or []
        self.excludeFoodModifier = excludeFoodModifier or []
        self.oralDiet = oralDiet
        self.supplement = supplement or []
        self.enteralFormula = enteralFormula
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "NutritionOrder":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "NutritionOrder":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ArtifactAssessment. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.RelatedArtifact import *
from fhirmodels.R5.Resource import *


class Content(FhirBaseModel):
    """A component comment, classifier, or rating of the artifact.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str informationType: comment | classifier | rating | container | response | change-request
    :param str summary: Brief summary of the content
    :param CodeableConcept type: What type of content
    :param CodeableConcept classifier: Rating, classifier, or assessment
    :param Quantity quantity: Quantitative rating
    :param Reference author: Who authored the content
    :param str path: What the comment is directed to
    :param RelatedArtifact relatedArtifact: Additional information
    :param bool freeToShare: Acceptable to publicly share the resource content
    :param Component component: Contained content
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "author": {"class_name": "Reference", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        informationType: "str" = None,
        summary: "str" = None,
        type: "CodeableConcept" = None,
        classifier: list["CodeableConcept"] = None,
        quantity: "Quantity" = None,
        author: "Reference" = None,
        path: list["str"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        freeToShare: "bool" = None,
        component: list["Component"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.informationType = informationType
        self.summary = summary
        self.type = type
        self.classifier = classifier or []
        self.quantity = quantity
        self.author = author
        self.path = path or []
        self.relatedArtifact = relatedArtifact or []
        self.freeToShare = freeToShare
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "ArtifactAssessment":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ArtifactAssessment":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ArtifactAssessment(DomainResource):
    """This Resource provides one or more comments, classifiers or ratings about a Resource and supports attribution and rights management metadata for the added content.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Additional identifier for the artifact assessment
    :param str title: A short title for the assessment for use in displaying and selecting
    :param Reference citeAsReference: How to cite the comment or rating
    :param str citeAsMarkdown: How to cite the comment or rating
    :param str date: Date last changed
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When the artifact assessment was approved by publisher
    :param str lastReviewDate: When the artifact assessment was last reviewed by the publisher
    :param Reference artifactReference: The artifact assessed, commented upon or rated
    :param str artifactCanonical: The artifact assessed, commented upon or rated
    :param str artifactUri: The artifact assessed, commented upon or rated
    :param Content content: Comment, classifier, or rating content
    :param str workflowStatus: submitted | triaged | waiting-for-input | resolved-no-change | resolved-change-required | deferred | duplicate | applied | published | entered-in-error
    :param str disposition: unresolved | not-persuasive | persuasive | persuasive-with-modification | not-persuasive-with-modification
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "citeAsReference": {"class_name": "Reference", "is_contained": False},
        "artifactReference": {"class_name": "Reference", "is_contained": False},
        "content": {"class_name": "Content", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        title: "str" = None,
        citeAsReference: "Reference" = None,
        citeAsMarkdown: "str" = None,
        date: "str" = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        artifactReference: "Reference" = None,
        artifactCanonical: "str" = None,
        artifactUri: "str" = None,
        content: list["Content"] = None,
        workflowStatus: "str" = None,
        disposition: "str" = None,
    ):

        self.resourceType = "ArtifactAssessment"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.title = title
        self.citeAsReference = citeAsReference
        self.citeAsMarkdown = citeAsMarkdown
        self.date = date
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.artifactReference = artifactReference
        self.artifactCanonical = artifactCanonical
        self.artifactUri = artifactUri
        self.content = content or []
        self.workflowStatus = workflowStatus
        self.disposition = disposition

    @classmethod
    def from_dict(cls, data: dict) -> "ArtifactAssessment":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ArtifactAssessment":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Observation. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Range import *
from fhirmodels.R5.Ratio import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.SampledData import *
from fhirmodels.R5.Timing import *


class TriggeredBy(FhirBaseModel):
    """Identifies the observation(s) that triggered the performance of this observation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference observation: Triggering observation
    :param str type: reflex | repeat | re-run
    :param str reason: Reason that the observation was triggered
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "observation": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        observation: "Reference" = None,
        type: "str" = None,
        reason: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.observation = observation
        self.type = type
        self.reason = reason

    @classmethod
    def from_dict(cls, data: dict) -> "Observation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Observation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ReferenceRange(FhirBaseModel):
    """Guidance on how to interpret the value by comparison to a normal or recommended range.  Multiple reference ranges are interpreted as an "OR".   In other words, to represent two distinct target populations, two `referenceRange` elements would be used.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity low: Low Range, if relevant
    :param Quantity high: High Range, if relevant
    :param CodeableConcept normalValue: Normal value, if relevant
    :param CodeableConcept type: Reference range qualifier
    :param CodeableConcept appliesTo: Reference range population
    :param Range age: Applicable age range, if relevant
    :param str text: Text based reference range in an observation
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "low": {"class_name": "Quantity", "is_contained": False},
        "high": {"class_name": "Quantity", "is_contained": False},
        "normalValue": {"class_name": "CodeableConcept", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "appliesTo": {"class_name": "CodeableConcept", "is_contained": False},
        "age": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        low: "Quantity" = None,
        high: "Quantity" = None,
        normalValue: "CodeableConcept" = None,
        type: "CodeableConcept" = None,
        appliesTo: list["CodeableConcept"] = None,
        age: "Range" = None,
        text: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.low = low
        self.high = high
        self.normalValue = normalValue
        self.type = type
        self.appliesTo = appliesTo or []
        self.age = age
        self.text = text

    @classmethod
    def from_dict(cls, data: dict) -> "Observation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Observation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Component(FhirBaseModel):
    """Some observations have multiple component observations.  These component observations are expressed as separate code value pairs that share the same attributes.  Examples include systolic and diastolic component observations for blood pressure measurement and multiple component observations for genetics observations.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Type of component observation (code / type)
    :param Quantity valueQuantity: Actual component result
    :param CodeableConcept valueCodeableConcept: Actual component result
    :param str valueString: Actual component result
    :param bool valueBoolean: Actual component result
    :param int valueInteger: Actual component result
    :param Range valueRange: Actual component result
    :param Ratio valueRatio: Actual component result
    :param SampledData valueSampledData: Actual component result
    :param str valueTime: Actual component result
    :param str valueDateTime: Actual component result
    :param Period valuePeriod: Actual component result
    :param Attachment valueAttachment: Actual component result
    :param Reference valueReference: Actual component result
    :param CodeableConcept dataAbsentReason: Why the component result is missing
    :param CodeableConcept interpretation: High, low, normal, etc
    :param ReferenceRange referenceRange: Provides guide for interpretation of component result
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueSampledData": {"class_name": "SampledData", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "dataAbsentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "interpretation": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceRange": {"class_name": "ReferenceRange", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueBoolean: "bool" = None,
        valueInteger: "int" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueSampledData: "SampledData" = None,
        valueTime: "str" = None,
        valueDateTime: "str" = None,
        valuePeriod: "Period" = None,
        valueAttachment: "Attachment" = None,
        valueReference: "Reference" = None,
        dataAbsentReason: "CodeableConcept" = None,
        interpretation: list["CodeableConcept"] = None,
        referenceRange: list["ReferenceRange"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.valueQuantity = valueQuantity
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueBoolean = valueBoolean
        self.valueInteger = valueInteger
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueSampledData = valueSampledData
        self.valueTime = valueTime
        self.valueDateTime = valueDateTime
        self.valuePeriod = valuePeriod
        self.valueAttachment = valueAttachment
        self.valueReference = valueReference
        self.dataAbsentReason = dataAbsentReason
        self.interpretation = interpretation or []
        self.referenceRange = referenceRange or []

    @classmethod
    def from_dict(cls, data: dict) -> "Observation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Observation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Observation(DomainResource):
    """Measurements and simple assertions made about a patient, device or other subject.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business Identifier for observation
    :param str instantiatesCanonical: Instantiates FHIR ObservationDefinition
    :param Reference instantiatesReference: Instantiates FHIR ObservationDefinition
    :param Reference basedOn: Fulfills plan, proposal or order
    :param TriggeredBy triggeredBy: Triggering observation(s)
    :param Reference partOf: Part of referenced event
    :param str status: registered | preliminary | final | amended +
    :param CodeableConcept category: Classification of  type of observation
    :param CodeableConcept code: Type of observation (code / type)
    :param Reference subject: Who and/or what the observation is about
    :param Reference focus: What the observation is about, when it is not about the subject of record
    :param Reference encounter: Healthcare event during which this observation is made
    :param str effectiveDateTime: Clinically relevant time/time-period for observation
    :param Period effectivePeriod: Clinically relevant time/time-period for observation
    :param Timing effectiveTiming: Clinically relevant time/time-period for observation
    :param str effectiveInstant: Clinically relevant time/time-period for observation
    :param str issued: Date/Time this version was made available
    :param Reference performer: Who is responsible for the observation
    :param Quantity valueQuantity: Actual result
    :param CodeableConcept valueCodeableConcept: Actual result
    :param str valueString: Actual result
    :param bool valueBoolean: Actual result
    :param int valueInteger: Actual result
    :param Range valueRange: Actual result
    :param Ratio valueRatio: Actual result
    :param SampledData valueSampledData: Actual result
    :param str valueTime: Actual result
    :param str valueDateTime: Actual result
    :param Period valuePeriod: Actual result
    :param Attachment valueAttachment: Actual result
    :param Reference valueReference: Actual result
    :param CodeableConcept dataAbsentReason: Why the result is missing
    :param CodeableConcept interpretation: High, low, normal, etc
    :param Annotation note: Comments about the observation
    :param CodeableConcept bodySite: Observed body part
    :param Reference bodyStructure: Observed body structure
    :param CodeableConcept method: How it was done
    :param Reference specimen: Specimen used for this observation
    :param Reference device: A reference to the device that generates the measurements or the device settings for the device
    :param ReferenceRange referenceRange: Provides guide for interpretation
    :param Reference hasMember: Related resource that belongs to the Observation group
    :param Reference derivedFrom: Related resource from which the observation is made
    :param Component component: Component results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "instantiatesReference": {"class_name": "Reference", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "triggeredBy": {"class_name": "TriggeredBy", "is_contained": True},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "focus": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "effectiveTiming": {"class_name": "Timing", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueRange": {"class_name": "Range", "is_contained": False},
        "valueRatio": {"class_name": "Ratio", "is_contained": False},
        "valueSampledData": {"class_name": "SampledData", "is_contained": False},
        "valuePeriod": {"class_name": "Period", "is_contained": False},
        "valueAttachment": {"class_name": "Attachment", "is_contained": False},
        "valueReference": {"class_name": "Reference", "is_contained": False},
        "dataAbsentReason": {"class_name": "CodeableConcept", "is_contained": False},
        "interpretation": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "bodySite": {"class_name": "CodeableConcept", "is_contained": False},
        "bodyStructure": {"class_name": "Reference", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "Reference", "is_contained": False},
        "referenceRange": {"class_name": "ReferenceRange", "is_contained": True},
        "hasMember": {"class_name": "Reference", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "component": {"class_name": "Component", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: "str" = None,
        instantiatesReference: "Reference" = None,
        basedOn: list["Reference"] = None,
        triggeredBy: list["TriggeredBy"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        focus: list["Reference"] = None,
        encounter: "Reference" = None,
        effectiveDateTime: "str" = None,
        effectivePeriod: "Period" = None,
        effectiveTiming: "Timing" = None,
        effectiveInstant: "str" = None,
        issued: "str" = None,
        performer: list["Reference"] = None,
        valueQuantity: "Quantity" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueString: "str" = None,
        valueBoolean: "bool" = None,
        valueInteger: "int" = None,
        valueRange: "Range" = None,
        valueRatio: "Ratio" = None,
        valueSampledData: "SampledData" = None,
        valueTime: "str" = None,
        valueDateTime: "str" = None,
        valuePeriod: "Period" = None,
        valueAttachment: "Attachment" = None,
        valueReference: "Reference" = None,
        dataAbsentReason: "CodeableConcept" = None,
        interpretation: list["CodeableConcept"] = None,
        note: list["Annotation"] = None,
        bodySite: "CodeableConcept" = None,
        bodyStructure: "Reference" = None,
        method: "CodeableConcept" = None,
        specimen: "Reference" = None,
        device: "Reference" = None,
        referenceRange: list["ReferenceRange"] = None,
        hasMember: list["Reference"] = None,
        derivedFrom: list["Reference"] = None,
        component: list["Component"] = None,
    ):

        self.resourceType = "Observation"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical
        self.instantiatesReference = instantiatesReference
        self.basedOn = basedOn or []
        self.triggeredBy = triggeredBy or []
        self.partOf = partOf or []
        self.status = status
        self.category = category or []
        self.code = code
        self.subject = subject
        self.focus = focus or []
        self.encounter = encounter
        self.effectiveDateTime = effectiveDateTime
        self.effectivePeriod = effectivePeriod
        self.effectiveTiming = effectiveTiming
        self.effectiveInstant = effectiveInstant
        self.issued = issued
        self.performer = performer or []
        self.valueQuantity = valueQuantity
        self.valueCodeableConcept = valueCodeableConcept
        self.valueString = valueString
        self.valueBoolean = valueBoolean
        self.valueInteger = valueInteger
        self.valueRange = valueRange
        self.valueRatio = valueRatio
        self.valueSampledData = valueSampledData
        self.valueTime = valueTime
        self.valueDateTime = valueDateTime
        self.valuePeriod = valuePeriod
        self.valueAttachment = valueAttachment
        self.valueReference = valueReference
        self.dataAbsentReason = dataAbsentReason
        self.interpretation = interpretation or []
        self.note = note or []
        self.bodySite = bodySite
        self.bodyStructure = bodyStructure
        self.method = method
        self.specimen = specimen
        self.device = device
        self.referenceRange = referenceRange or []
        self.hasMember = hasMember or []
        self.derivedFrom = derivedFrom or []
        self.component = component or []

    @classmethod
    def from_dict(cls, data: dict) -> "Observation":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Observation":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DiagnosticReport. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class SupportingInfo(FhirBaseModel):
    """This backbone element contains supporting information that was used in the creation of the report not included in the results already included in the report.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Supporting information role code
    :param Reference reference: Supporting information reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        reference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "DiagnosticReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DiagnosticReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Media(FhirBaseModel):
    """A list of key images or data associated with this report. The images or data are generally created during the diagnostic process, and may be directly of the patient, or of treated specimens (i.e. slides of interest).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str comment: Comment about the image or data (e.g. explanation)
    :param Reference link: Reference to the image or data source
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "link": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        comment: "str" = None,
        link: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.comment = comment
        self.link = link

    @classmethod
    def from_dict(cls, data: dict) -> "DiagnosticReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DiagnosticReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DiagnosticReport(DomainResource):
    """The findings and interpretation of diagnostic tests performed on patients, groups of patients, products, substances, devices, and locations, and/or specimens derived from these. The report includes clinical context such as requesting provider information, and some mix of atomic results, images, textual and coded interpretations, and formatted representation of diagnostic reports. The report also includes non-clinical context such as batch analysis and stability reporting of products and substances.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for report
    :param Reference basedOn: What was requested
    :param str status: registered | partial | preliminary | modified | final | amended | corrected | appended | cancelled | entered-in-error | unknown
    :param CodeableConcept category: Service category
    :param CodeableConcept code: Name/Code for this diagnostic report
    :param Reference subject: The subject of the report - usually, but not always, the patient
    :param Reference encounter: Health care event when test ordered
    :param str effectiveDateTime: Clinically relevant time/time-period for report
    :param Period effectivePeriod: Clinically relevant time/time-period for report
    :param str issued: DateTime this version was made
    :param Reference performer: Responsible Diagnostic Service
    :param Reference resultsInterpreter: Primary result interpreter
    :param Reference specimen: Specimens this report is based on
    :param Reference result: Observations
    :param Annotation note: Comments about the diagnostic report
    :param Reference study: Reference to full details of an analysis associated with the diagnostic report
    :param SupportingInfo supportingInfo: Additional information supporting the diagnostic report
    :param Media media: Key images or data associated with this report
    :param Reference composition: Reference to a Composition resource for the DiagnosticReport structure
    :param str conclusion: Clinical conclusion (interpretation) of test results
    :param CodeableConcept conclusionCode: Codes for the clinical conclusion of test results
    :param Attachment presentedForm: Entire report as issued
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "resultsInterpreter": {"class_name": "Reference", "is_contained": False},
        "specimen": {"class_name": "Reference", "is_contained": False},
        "result": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "study": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "SupportingInfo", "is_contained": True},
        "media": {"class_name": "Media", "is_contained": True},
        "composition": {"class_name": "Reference", "is_contained": False},
        "conclusionCode": {"class_name": "CodeableConcept", "is_contained": False},
        "presentedForm": {"class_name": "Attachment", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        status: "str" = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        effectiveDateTime: "str" = None,
        effectivePeriod: "Period" = None,
        issued: "str" = None,
        performer: list["Reference"] = None,
        resultsInterpreter: list["Reference"] = None,
        specimen: list["Reference"] = None,
        result: list["Reference"] = None,
        note: list["Annotation"] = None,
        study: list["Reference"] = None,
        supportingInfo: list["SupportingInfo"] = None,
        media: list["Media"] = None,
        composition: "Reference" = None,
        conclusion: "str" = None,
        conclusionCode: list["CodeableConcept"] = None,
        presentedForm: list["Attachment"] = None,
    ):

        self.resourceType = "DiagnosticReport"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.status = status
        self.category = category or []
        self.code = code
        self.subject = subject
        self.encounter = encounter
        self.effectiveDateTime = effectiveDateTime
        self.effectivePeriod = effectivePeriod
        self.issued = issued
        self.performer = performer or []
        self.resultsInterpreter = resultsInterpreter or []
        self.specimen = specimen or []
        self.result = result or []
        self.note = note or []
        self.study = study or []
        self.supportingInfo = supportingInfo or []
        self.media = media or []
        self.composition = composition
        self.conclusion = conclusion
        self.conclusionCode = conclusionCode or []
        self.presentedForm = presentedForm or []

    @classmethod
    def from_dict(cls, data: dict) -> "DiagnosticReport":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DiagnosticReport":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
